
files_c=[
 'C/7zBuf2.c',
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/7zStream.c',
 'C/Aes.c',
 'C/Alloc.c',
 'C/Bcj2.c',
 'C/Bcj2Enc.c',
 'C/Blake2s.c',
 'C/Bra.c',
 'C/Bra86.c',
 'C/BraIA64.c',
 'C/BwtSort.c',
 'C/CpuArch.c',
 'C/Delta.c',
 'C/HuffEnc.c',
 'C/LzFind.c',
 'C/LzFindMt.c',
 'C/Lzma2Dec.c',
 'C/Lzma2Enc.c',
 'C/LzmaDec.c',
 'C/LzmaEnc.c',
 'C/MtCoder.c',
 'C/Ppmd7.c',
 'C/Ppmd7Dec.c',
 'C/Ppmd7Enc.c',
 'C/Ppmd8.c',
 'C/Ppmd8Dec.c',
 'C/Ppmd8Enc.c',
 'C/Sha1.c',
 'C/Sha256.c',
 'C/Sort.c',
 'C/Threads.c',
 'C/Xz.c',
 'C/XzCrc64.c',
 'C/XzCrc64Opt.c',
 'C/XzDec.c',
 'C/XzEnc.c',
 'C/XzIn.c',
]

files_cpp=[
 'CPP/7zip/Archive/7z/7zCompressionMode.cpp',
 'CPP/7zip/Archive/7z/7zDecode.cpp',
 'CPP/7zip/Archive/7z/7zEncode.cpp',
 'CPP/7zip/Archive/7z/7zExtract.cpp',
 'CPP/7zip/Archive/7z/7zFolderInStream.cpp',
 'CPP/7zip/Archive/7z/7zHandler.cpp',
 'CPP/7zip/Archive/7z/7zHandlerOut.cpp',
 'CPP/7zip/Archive/7z/7zHeader.cpp',
 'CPP/7zip/Archive/7z/7zIn.cpp',
 'CPP/7zip/Archive/7z/7zOut.cpp',
 'CPP/7zip/Archive/7z/7zProperties.cpp',
 'CPP/7zip/Archive/7z/7zRegister.cpp',
 'CPP/7zip/Archive/7z/7zSpecStream.cpp',
 'CPP/7zip/Archive/7z/7zUpdate.cpp',
 'CPP/7zip/Archive/ApmHandler.cpp',
 'CPP/7zip/Archive/ArHandler.cpp',
 'CPP/7zip/Archive/ArchiveExports.cpp',
 'CPP/7zip/Archive/ArjHandler.cpp',
 'CPP/7zip/Archive/Bz2Handler.cpp',
 'CPP/7zip/Archive/Cab/CabBlockInStream.cpp',
 'CPP/7zip/Archive/Cab/CabHandler.cpp',
 'CPP/7zip/Archive/Cab/CabHeader.cpp',
 'CPP/7zip/Archive/Cab/CabIn.cpp',
 'CPP/7zip/Archive/Cab/CabRegister.cpp',
 'CPP/7zip/Archive/Chm/ChmHandler.cpp',
 'CPP/7zip/Archive/Chm/ChmIn.cpp',
 'CPP/7zip/Archive/ComHandler.cpp',
 'CPP/7zip/Archive/Common/CoderMixer2.cpp',
 'CPP/7zip/Archive/Common/DummyOutStream.cpp',
 'CPP/7zip/Archive/Common/FindSignature.cpp',
 'CPP/7zip/Archive/Common/HandlerOut.cpp',
 'CPP/7zip/Archive/Common/InStreamWithCRC.cpp',
 'CPP/7zip/Archive/Common/ItemNameUtils.cpp',
 'CPP/7zip/Archive/Common/MultiStream.cpp',
 'CPP/7zip/Archive/Common/OutStreamWithCRC.cpp',
 'CPP/7zip/Archive/Common/OutStreamWithSha1.cpp',
 'CPP/7zip/Archive/Common/ParseProperties.cpp',
 'CPP/7zip/Archive/CpioHandler.cpp',
 'CPP/7zip/Archive/CramfsHandler.cpp',
 'CPP/7zip/Archive/DeflateProps.cpp',
 'CPP/7zip/Archive/DllExports2.cpp',
 'CPP/7zip/Archive/DmgHandler.cpp',
 'CPP/7zip/Archive/ElfHandler.cpp',
 'CPP/7zip/Archive/ExtHandler.cpp',
 'CPP/7zip/Archive/FatHandler.cpp',
 'CPP/7zip/Archive/FlvHandler.cpp',
 'CPP/7zip/Archive/GzHandler.cpp',
 'CPP/7zip/Archive/GptHandler.cpp',
 'CPP/7zip/Archive/HandlerCont.cpp',
 'CPP/7zip/Archive/HfsHandler.cpp',
 'CPP/7zip/Archive/IhexHandler.cpp',
 'CPP/7zip/Archive/Iso/IsoHandler.cpp',
 'CPP/7zip/Archive/Iso/IsoHeader.cpp',
 'CPP/7zip/Archive/Iso/IsoIn.cpp',
 'CPP/7zip/Archive/Iso/IsoRegister.cpp',
 'CPP/7zip/Archive/LzhHandler.cpp',
 'CPP/7zip/Archive/LzmaHandler.cpp',
 'CPP/7zip/Archive/MachoHandler.cpp',
 'CPP/7zip/Archive/MbrHandler.cpp',
 'CPP/7zip/Archive/MslzHandler.cpp',
 'CPP/7zip/Archive/MubHandler.cpp',
 'CPP/7zip/Archive/Nsis/NsisDecode.cpp',
 'CPP/7zip/Archive/Nsis/NsisHandler.cpp',
 'CPP/7zip/Archive/Nsis/NsisIn.cpp',
 'CPP/7zip/Archive/Nsis/NsisRegister.cpp',
 'CPP/7zip/Archive/NtfsHandler.cpp',
 'CPP/7zip/Archive/PeHandler.cpp',
 'CPP/7zip/Archive/PpmdHandler.cpp',
 'CPP/7zip/Archive/QcowHandler.cpp',
 'CPP/7zip/Archive/Rar/RarHandler.cpp',
 'CPP/7zip/Archive/Rar/Rar5Handler.cpp',
 'CPP/7zip/Archive/RpmHandler.cpp',
 'CPP/7zip/Archive/SplitHandler.cpp',
 'CPP/7zip/Archive/SquashfsHandler.cpp',
 'CPP/7zip/Archive/SwfHandler.cpp',
 'CPP/7zip/Archive/Tar/TarHandler.cpp',
 'CPP/7zip/Archive/Tar/TarHandlerOut.cpp',
 'CPP/7zip/Archive/Tar/TarHeader.cpp',
 'CPP/7zip/Archive/Tar/TarIn.cpp',
 'CPP/7zip/Archive/Tar/TarOut.cpp',
 'CPP/7zip/Archive/Tar/TarRegister.cpp',
 'CPP/7zip/Archive/Tar/TarUpdate.cpp',
 'CPP/7zip/Archive/Udf/UdfHandler.cpp',
 'CPP/7zip/Archive/Udf/UdfIn.cpp',
 'CPP/7zip/Archive/UefiHandler.cpp',
 'CPP/7zip/Archive/VdiHandler.cpp',
 'CPP/7zip/Archive/VhdHandler.cpp',
 'CPP/7zip/Archive/VmdkHandler.cpp',
 'CPP/7zip/Archive/Wim/WimHandler.cpp',
 'CPP/7zip/Archive/Wim/WimHandlerOut.cpp',
 'CPP/7zip/Archive/Wim/WimIn.cpp',
 'CPP/7zip/Archive/Wim/WimRegister.cpp',
 'CPP/7zip/Archive/XarHandler.cpp',
 'CPP/7zip/Archive/XzHandler.cpp',
 'CPP/7zip/Archive/ZHandler.cpp',
 'CPP/7zip/Archive/Zip/ZipAddCommon.cpp',
 'CPP/7zip/Archive/Zip/ZipHandler.cpp',
 'CPP/7zip/Archive/Zip/ZipHandlerOut.cpp',
 'CPP/7zip/Archive/Zip/ZipIn.cpp',
 'CPP/7zip/Archive/Zip/ZipItem.cpp',
 'CPP/7zip/Archive/Zip/ZipOut.cpp',
 'CPP/7zip/Archive/Zip/ZipRegister.cpp',
 'CPP/7zip/Archive/Zip/ZipUpdate.cpp',
 'CPP/7zip/Common/CWrappers.cpp',
 'CPP/7zip/Common/CreateCoder.cpp',
 'CPP/7zip/Common/FilterCoder.cpp',
 'CPP/7zip/Common/InBuffer.cpp',
 'CPP/7zip/Common/InOutTempBuffer.cpp',
 'CPP/7zip/Common/LimitedStreams.cpp',
 'CPP/7zip/Common/MemBlocks.cpp',
 'CPP/7zip/Common/MethodId.cpp',
 'CPP/7zip/Common/MethodProps.cpp',
 'CPP/7zip/Common/OffsetStream.cpp',
 'CPP/7zip/Common/OutBuffer.cpp',
 'CPP/7zip/Common/OutMemStream.cpp',
 'CPP/7zip/Common/ProgressMt.cpp',
 'CPP/7zip/Common/ProgressUtils.cpp',
 'CPP/7zip/Common/PropId.cpp',
 'CPP/7zip/Common/StreamBinder.cpp',
 'CPP/7zip/Common/StreamObjects.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Common/UniqBlocks.cpp',
 'CPP/7zip/Common/VirtThread.cpp',
 'CPP/7zip/Compress/BZip2Crc.cpp',
 'CPP/7zip/Compress/BZip2Decoder.cpp',
 'CPP/7zip/Compress/BZip2Encoder.cpp',
 'CPP/7zip/Compress/BZip2Register.cpp',
 'CPP/7zip/Compress/Bcj2Coder.cpp',
 'CPP/7zip/Compress/Bcj2Register.cpp',
 'CPP/7zip/Compress/BcjCoder.cpp',
 'CPP/7zip/Compress/BcjRegister.cpp',
 'CPP/7zip/Compress/BitlDecoder.cpp',
 'CPP/7zip/Compress/BranchMisc.cpp',
 'CPP/7zip/Compress/BranchRegister.cpp',
 'CPP/7zip/Compress/ByteSwap.cpp',
 'CPP/7zip/Compress/CodecExports.cpp',
 'CPP/7zip/Compress/CopyCoder.cpp',
 'CPP/7zip/Compress/CopyRegister.cpp',
 'CPP/7zip/Compress/Deflate64Register.cpp',
 'CPP/7zip/Compress/DeflateDecoder.cpp',
 'CPP/7zip/Compress/DeflateEncoder.cpp',
 'CPP/7zip/Compress/DeflateRegister.cpp',
 'CPP/7zip/Compress/DeltaFilter.cpp',
 'CPP/7zip/Compress/ImplodeDecoder.cpp',
 'CPP/7zip/Compress/ImplodeHuffmanDecoder.cpp',
 'CPP/7zip/Compress/LzOutWindow.cpp',
 'CPP/7zip/Compress/LzhDecoder.cpp',
 'CPP/7zip/Compress/Lzma2Decoder.cpp',
 'CPP/7zip/Compress/Lzma2Encoder.cpp',
 'CPP/7zip/Compress/Lzma2Register.cpp',
 'CPP/7zip/Compress/LzmaDecoder.cpp',
 'CPP/7zip/Compress/LzmaEncoder.cpp',
 'CPP/7zip/Compress/LzmaRegister.cpp',
 'CPP/7zip/Compress/LzmsDecoder.cpp',
 'CPP/7zip/Compress/LzxDecoder.cpp',
 'CPP/7zip/Compress/PpmdDecoder.cpp',
 'CPP/7zip/Compress/PpmdEncoder.cpp',
 'CPP/7zip/Compress/PpmdRegister.cpp',
 'CPP/7zip/Compress/PpmdZip.cpp',
 'CPP/7zip/Compress/QuantumDecoder.cpp',
 'CPP/7zip/Compress/ShrinkDecoder.cpp',
 'CPP/7zip/Compress/ZDecoder.cpp',
 'CPP/7zip/Compress/XpressDecoder.cpp',
 'CPP/7zip/Compress/ZlibDecoder.cpp',
 'CPP/7zip/Compress/ZlibEncoder.cpp',
 'CPP/7zip/Crypto/7zAes.cpp',
 'CPP/7zip/Crypto/7zAesRegister.cpp',
 'CPP/7zip/Crypto/HmacSha1.cpp',
 'CPP/7zip/Crypto/HmacSha256.cpp',
 'CPP/7zip/Crypto/MyAes.cpp',
 'CPP/7zip/Crypto/MyAesReg.cpp',
 'CPP/7zip/Crypto/Pbkdf2HmacSha1.cpp',
 'CPP/7zip/Crypto/RandGen.cpp',
 'CPP/7zip/Crypto/Rar20Crypto.cpp',
 'CPP/7zip/Crypto/Rar5Aes.cpp',
 'CPP/7zip/Crypto/RarAes.cpp',
 'CPP/7zip/Crypto/WzAes.cpp',
 'CPP/7zip/Crypto/ZipCrypto.cpp',
 'CPP/7zip/Crypto/ZipStrong.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/CrcReg.cpp',
 'CPP/Common/DynLimBuf.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/MyMap.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/MyXml.cpp',
 'CPP/Common/NewHandler.cpp',
 'CPP/Common/Sha1Reg.cpp',
 'CPP/Common/Sha256Reg.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/StringToInt.cpp',
 'CPP/Common/UTFConvert.cpp',
 'CPP/Common/Wildcard.cpp',
 'CPP/Common/XzCrc64Reg.cpp',
 'CPP/Windows/FileDir.cpp',
 'CPP/Windows/FileFind.cpp',
 'CPP/Windows/FileIO.cpp',
 'CPP/Windows/FileName.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/PropVariantUtils.cpp',
 'CPP/Windows/Synchronization.cpp',
 'CPP/Windows/System.cpp',
 'CPP/Windows/TimeUtils.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]





files_c=[
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/Alloc.c',
 'C/CpuArch.c',
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/Archive/Common/OutStreamWithCRC.cpp',
 'CPP/7zip/Common/CreateCoder.cpp',
 'CPP/7zip/Common/FilePathAutoRename.cpp',
 'CPP/7zip/Common/FileStreams.cpp',
 'CPP/7zip/Common/FilterCoder.cpp',
 'CPP/7zip/Common/LimitedStreams.cpp',
 'CPP/7zip/Common/MethodProps.cpp',
 'CPP/7zip/Common/ProgressUtils.cpp',
 'CPP/7zip/Common/PropId.cpp',
 'CPP/7zip/Common/StreamObjects.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Common/UniqBlocks.cpp',
 'CPP/7zip/Compress/CopyCoder.cpp',
 'CPP/7zip/UI/Common/ArchiveCommandLine.cpp',
 'CPP/7zip/UI/Common/ArchiveExtractCallback.cpp',
 'CPP/7zip/UI/Common/ArchiveOpenCallback.cpp',
 'CPP/7zip/UI/Common/Bench.cpp',
 'CPP/7zip/UI/Common/DefaultName.cpp',
 'CPP/7zip/UI/Common/EnumDirItems.cpp',
 'CPP/7zip/UI/Common/Extract.cpp',
 'CPP/7zip/UI/Common/ExtractingFilePath.cpp',
 'CPP/7zip/UI/Common/HashCalc.cpp',
 'CPP/7zip/UI/Common/LoadCodecs.cpp',
 'CPP/7zip/UI/Common/OpenArchive.cpp',
 'CPP/7zip/UI/Common/PropIDUtils.cpp',
 'CPP/7zip/UI/Common/SetProperties.cpp',
 'CPP/7zip/UI/Common/SortUtils.cpp',
 'CPP/7zip/UI/Common/TempFiles.cpp',
 'CPP/7zip/UI/Common/Update.cpp',
 'CPP/7zip/UI/Common/UpdateAction.cpp',
 'CPP/7zip/UI/Common/UpdateCallback.cpp',
 'CPP/7zip/UI/Common/UpdatePair.cpp',
 'CPP/7zip/UI/Common/UpdateProduce.cpp',
 'CPP/7zip/UI/Console/BenchCon.cpp',
 'CPP/7zip/UI/Console/ConsoleClose.cpp',
 'CPP/7zip/UI/Console/ExtractCallbackConsole.cpp',
 'CPP/7zip/UI/Console/HashCon.cpp',
 'CPP/7zip/UI/Console/List.cpp',
 'CPP/7zip/UI/Console/Main.cpp',
 'CPP/7zip/UI/Console/MainAr.cpp',
 'CPP/7zip/UI/Console/OpenCallbackConsole.cpp',
 'CPP/7zip/UI/Console/PercentPrinter.cpp',
 'CPP/7zip/UI/Console/UpdateCallbackConsole.cpp',
 'CPP/7zip/UI/Console/UserInputUtils.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/CommandLineParser.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/ListFileUtils.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/NewHandler.cpp',
 'CPP/Common/StdInStream.cpp',
 'CPP/Common/StdOutStream.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/StringToInt.cpp',
 'CPP/Common/UTFConvert.cpp',
 'CPP/Common/Wildcard.cpp',
 'CPP/Windows/DLL.cpp',
 'CPP/Windows/ErrorMsg.cpp',
 'CPP/Windows/FileDir.cpp',
 'CPP/Windows/FileFind.cpp',
 'CPP/Windows/FileIO.cpp',
 'CPP/Windows/FileName.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/PropVariantConv.cpp',
 'CPP/Windows/System.cpp',
 'CPP/Windows/TimeUtils.cpp',
 'CPP/myWindows/myAddExeFlag.cpp',
 'CPP/myWindows/mySplitCommandLine.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]





files_c=[
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/Alloc.c',
 'C/CpuArch.c',
 'C/Sha256.c',
 'C/Sort.c',
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/Archive/Common/OutStreamWithCRC.cpp',
 'CPP/7zip/Common/CreateCoder.cpp',
 'CPP/7zip/Common/FilePathAutoRename.cpp',
 'CPP/7zip/Common/FileStreams.cpp',
 'CPP/7zip/Common/FilterCoder.cpp',
 'CPP/7zip/Common/LimitedStreams.cpp',
 'CPP/7zip/Common/MethodProps.cpp',
 'CPP/7zip/Common/ProgressUtils.cpp',
 'CPP/7zip/Common/PropId.cpp',
 'CPP/7zip/Common/StreamObjects.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Common/UniqBlocks.cpp',
 'CPP/7zip/Compress/CopyCoder.cpp',
 'CPP/7zip/UI/Agent/Agent.cpp',
 'CPP/7zip/UI/Agent/AgentOut.cpp',
 'CPP/7zip/UI/Agent/AgentProxy.cpp',
 'CPP/7zip/UI/Agent/ArchiveFolder.cpp',
 'CPP/7zip/UI/Agent/ArchiveFolderOpen.cpp',
 'CPP/7zip/UI/Agent/ArchiveFolderOut.cpp',
 'CPP/7zip/UI/Agent/UpdateCallbackAgent.cpp',
 'CPP/7zip/UI/Common/ArchiveExtractCallback.cpp',
 'CPP/7zip/UI/Common/ArchiveName.cpp',
 'CPP/7zip/UI/Common/ArchiveOpenCallback.cpp',
 'CPP/7zip/UI/Common/CompressCall.cpp',
 'CPP/7zip/UI/Common/DefaultName.cpp',
 'CPP/7zip/UI/Common/EnumDirItems.cpp',
 'CPP/7zip/UI/Common/ExtractingFilePath.cpp',
 'CPP/7zip/UI/Common/HashCalc.cpp',
 'CPP/7zip/UI/Common/LoadCodecs.cpp',
 'CPP/7zip/UI/Common/OpenArchive.cpp',
 'CPP/7zip/UI/Common/PropIDUtils.cpp',
 'CPP/7zip/UI/Common/SetProperties.cpp',
 'CPP/7zip/UI/Common/SortUtils.cpp',
 'CPP/7zip/UI/Common/UpdateAction.cpp',
 'CPP/7zip/UI/Common/UpdateCallback.cpp',
 'CPP/7zip/UI/Common/UpdatePair.cpp',
 'CPP/7zip/UI/Common/UpdateProduce.cpp',
 'CPP/7zip/UI/Common/WorkDir.cpp',
 'CPP/7zip/UI/Common/ZipRegistry.cpp',
 'CPP/7zip/UI/FileManager/App.cpp',
 'CPP/7zip/UI/FileManager/ClassDefs.cpp',
 'CPP/7zip/UI/FileManager/ComboDialog.cpp',
 'CPP/7zip/UI/FileManager/ComboDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/CopyDialog.cpp',
 'CPP/7zip/UI/FileManager/CopyDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/ExtractCallback.cpp',
 'CPP/7zip/UI/FileManager/FM.cpp',
 'CPP/7zip/UI/FileManager/FM_rc.cpp',
 'CPP/7zip/UI/FileManager/FSDrives.cpp',
 'CPP/7zip/UI/FileManager/FSFolder.cpp',
 'CPP/7zip/UI/FileManager/FSFolderCopy.cpp',
 'CPP/7zip/UI/FileManager/FileFolderPluginOpen.cpp',
 'CPP/7zip/UI/FileManager/FormatUtils.cpp',
 'CPP/7zip/UI/FileManager/LangUtils.cpp',
 'CPP/7zip/UI/FileManager/ListViewDialog.cpp',
 'CPP/7zip/UI/FileManager/ListViewDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/MessagesDialog.cpp',
 'CPP/7zip/UI/FileManager/MessagesDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/MyLoadMenu.cpp',
 'CPP/7zip/UI/FileManager/OpenCallback.cpp',
 'CPP/7zip/UI/FileManager/OverwriteDialog.cpp',
 'CPP/7zip/UI/FileManager/OverwriteDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/Panel.cpp',
 'CPP/7zip/UI/FileManager/PanelCopy.cpp',
 'CPP/7zip/UI/FileManager/PanelCrc.cpp',
 'CPP/7zip/UI/FileManager/PanelFolderChange.cpp',
 'CPP/7zip/UI/FileManager/PanelItemOpen.cpp',
 'CPP/7zip/UI/FileManager/PanelItems.cpp',
 'CPP/7zip/UI/FileManager/PanelListNotify.cpp',
 'CPP/7zip/UI/FileManager/PanelMenu.cpp',
 'CPP/7zip/UI/FileManager/PanelOperations.cpp',
 'CPP/7zip/UI/FileManager/PanelSelect.cpp',
 'CPP/7zip/UI/FileManager/PanelSort.cpp',
 'CPP/7zip/UI/FileManager/PanelSplitFile.cpp',
 'CPP/7zip/UI/FileManager/PasswordDialog.cpp',
 'CPP/7zip/UI/FileManager/PasswordDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/ProgramLocation.cpp',
 'CPP/7zip/UI/FileManager/ProgressDialog2.cpp',
 'CPP/7zip/UI/FileManager/ProgressDialog2_rc.cpp',
 'CPP/7zip/UI/FileManager/PropertyName.cpp',
 'CPP/7zip/UI/FileManager/RegistryUtils.cpp',
 'CPP/7zip/UI/FileManager/RootFolder.cpp',
 'CPP/7zip/UI/FileManager/SplitDialog.cpp',
 'CPP/7zip/UI/FileManager/SplitDialog_rc.cpp',
 'CPP/7zip/UI/FileManager/SplitUtils.cpp',
 'CPP/7zip/UI/FileManager/StringUtils.cpp',
 'CPP/7zip/UI/FileManager/SysIconUtils.cpp',
 'CPP/7zip/UI/FileManager/TextPairs.cpp',
 'CPP/7zip/UI/FileManager/UpdateCallback100.cpp',
 'CPP/7zip/UI/FileManager/ViewSettings.cpp',
 'CPP/7zip/UI/FileManager/wxFM.cpp',
 'CPP/7zip/UI/GUI/HashGUI.cpp',
 'CPP/7zip/UI/GUI/UpdateCallbackGUI2.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/CrcReg.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/Lang.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/NewHandler.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/StringToInt.cpp',
 'CPP/Common/TextConfig.cpp',
 'CPP/Common/UTFConvert.cpp',
 'CPP/Common/Wildcard.cpp',
 'CPP/Windows/Clipboard.cpp',
 'CPP/Windows/Control/Controls.cpp',
 'CPP/Windows/Control/Dialog.cpp',
 'CPP/Windows/Control/Window2.cpp',
 'CPP/Windows/DLL.cpp',
 'CPP/Windows/ErrorMsg.cpp',
 'CPP/Windows/FileDir.cpp',
 'CPP/Windows/FileFind.cpp',
 'CPP/Windows/FileIO.cpp',
 'CPP/Windows/FileName.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/PropVariantConv.cpp',
 'CPP/Windows/Registry.cpp',
 'CPP/Windows/Synchronization.cpp',
 'CPP/Windows/System.cpp',
 'CPP/Windows/TimeUtils.cpp',
 'CPP/Windows/Window.cpp',
 'CPP/myWindows/wine_GetXXXDefaultLangID.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]





files_c=[
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/TEST/TestUI/TestUI.cpp',
 'CPP/7zip/UI/FileManager/PasswordDialog.cpp',
 'CPP/7zip/UI/FileManager/PasswordDialog_rc.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Windows/Control/Controls.cpp',
 'CPP/Windows/Control/Dialog.cpp',
 'CPP/Windows/Window.cpp',
]




#!/usr/bin/env python

import os
import sys

class Structure:
	def __init__(self, **kwds):
		self.__dict__.update(kwds)

TYPE_EXE=0
TYPE_DLL=1

def generate_pro(filename,project):
	
	if os.path.isfile(filename):
		os.remove(filename)

	f=open(filename,'w')
	f.write('''
# WARNING : automatically generated by utils/generate.py

QT -= core gui
TARGET = ''' + project.name   + '''
''')
	if project.type == TYPE_EXE:
		f.write('''
CONFIG += console
CONFIG -= app_bundle
TEMPLATE = app
''')
	if project.type == TYPE_DLL:
		f.write('''
CONFIG += dll
TEMPLATE = lib
''')

	f.write('''
DESTDIR = ../../../../bin

unix: LIBS += -ldl

DEFINES+=USE_LIB7Z_DLL

''')
	f.write('INCLUDEPATH = \\\n')
	for file in project.includedirs:
		f.write("  {} \\\n".format(file))
	f.write('\n')
	for d in project.defines:
		f.write("DEFINES += " + d + '\n')	
	f.write('\n')
	f.write('SOURCES +=  \\\n')
	for file in project.files_c:
		f.write("  ../../../../{} \\\n".format(file))
	for file in project.files_cpp:
		f.write("  ../../../../{} \\\n".format(file))

	f.write('''
macx: LIBS += -framework CoreFoundation
''')
	f.write('\n')
	f.close()

premake4_headers='''
-- WARNING : automatically generated by utils/generate.py
solution "p7zip"
   configurations { "Debug", "Release" }

-- includes for all projects
      includedirs {
'''

def generate_premake4(filename,project):
	
	if os.path.isfile(filename):
		os.remove(filename)

	f=open(filename,'w')
	f.write(premake4_headers)
	for file in project.includedirs:
		f.write('        "{}",\n'.format(file))
	f.write('      }\n\n')
	defines=""
	for d in project.defines:
		defines+= ', "' + d + '"'	
	f.write('      configuration "Debug"\n')
	f.write('         defines { "DEBUG"' + defines + ' }\n')
	f.write('         flags { "Symbols" }\n')
	f.write('\n')
	f.write('      configuration "Release"\n')
	f.write('         defines { "NDEBUG"' + defines + ' }\n')
	f.write('         flags { "Optimize" }    \n')
	f.write('\n')
	f.write('   project "all_c_code"\n')
	f.write('     kind "StaticLib"\n')
	f.write('      language "C"\n')
	f.write('      files {\n')
	for file in project.files_c:
		f.write('      "../../../../{}",\n'.format(file))
	f.write('''      }
 
---------------------------------
   project "''' + project.name + '''"
      kind "ConsoleApp"
      language "C++"
      files {
''')
	for file in project.files_cpp:
		f.write('      "../../../../{}",\n'.format(file))
	f.write('''
      }

      configuration "linux"
	links       {  "all_c_code", "pthread" } 
''')

	f.close()

def generate_cmake(filename,project):
	
	if os.path.isfile(filename):
		os.remove(filename)

	f=open(filename,'w')
	f.write('''

# WARNING : automatically generated by utils/generate.py
cmake_minimum_required(VERSION 2.8)

''')
	f.write('include_directories(\n')
	for file in project.includedirs:
		f.write('  "{}"\n'.format(file))
	f.write(')\n\n')
	defines=""
	for d in project.defines:
		defines+= ' -D' + d
	f.write('add_definitions(' + defines + ')\n')
	f.write('''
IF(APPLE)
  add_definitions(-DENV_MACOSX)
  FIND_LIBRARY(COREFOUNDATION_LIBRARY CoreFoundation )
ENDIF(APPLE)

''')
	if project.type == TYPE_EXE:
		f.write('add_executable(' + project.name2 + '\n\n')
	if project.type == TYPE_DLL:
		f.write('add_library(' + project.name2 + ' MODULE\n\n')
	for file in project.files_c:
		f.write('  "../../../../{}"\n'.format(file))
	for file in project.files_cpp:
		f.write('  "../../../../{}"\n'.format(file))
	f.write(')\n')
	f.write(project.cmake_end)
	f.close()

def to_obj(file):
	file2=os.path.basename(file)
	return os.path.splitext(file2)[0] + '.o'

def generate_makefile_list(filename,project,bin_dir='../../../../bin'):
	
	if os.path.isfile(filename):
		os.remove(filename)

	f=open(filename,'w')
	f.write('''

# WARNING : automatically generated by utils/generate.py

''')
	if project.type == TYPE_EXE:
		f.write('PROG={}/{}$(BINSUFFIX)\n\n'.format(bin_dir,project.name))
	if project.type == TYPE_DLL:
		f.write('PROG={}/{}.so\n\n'.format(bin_dir,project.name))

	f.write('all: $(PCH_NAME) $(PROG)\n\n')

	f.write('LOCAL_FLAGS=$(TARGET_FLAGS) \\\n')
	for d in project.defines:
		f.write('  -D{} \\\n'.format(d))	
	f.write('\n')
	f.write('SRCS=\\\n')
	for file in project.files_cpp:
		f.write('  ../../../../{} \\\n'.format(file))
	f.write('\n')
	f.write('SRCS_C=\\\n')
	for file in project.files_c:
		f.write('  ../../../../{} \\\n'.format(file))
	f.write('''
StdAfx.h.gch : ../../../myWindows/StdAfx.h
\trm -f StdAfx.h.gch
\t$(CXX) $(CXXFLAGS) ../../../myWindows/StdAfx.h -o StdAfx.h.gch
''')

	for file in project.files_c:
		file='../../../../' + file
		f.write('{} : {}\n'.format(to_obj(file),file))
		f.write('\t$(CC) $(CFLAGS) {}\n'.format(file))
	for file in project.files_cpp:
		file='../../../../' + file
		f.write('{} : {}\n'.format(to_obj(file),file))
		f.write('\t$(CXX) $(CXXFLAGS) {}\n'.format(file))

	f.write('\nOBJS=\\\n')
	for file in project.files_c:
		file=to_obj(file)
		if file == '7zCrcOpt.o':
			f.write(' $(OBJ_CRC32) \\\n')
		else:
			f.write(' {} \\\n'.format(file))
	for file in project.files_cpp:
		f.write(' {} \\\n'.format(to_obj(file)))
	if project.need_AES:
		f.write(' $(OBJ_AES) \\\n')
		
	f.write('\n')


	f.close()

def generate_android_mk(filename,project):

	if os.path.isfile(filename):
		os.remove(filename)

	f=open(filename,'w')
	f.write('''# 
# build {} for armeabi and armeabi-v7a CPU
#
# WARNING : file generated by generate.py
#


LOCAL_PATH := $(call my-dir)

include $(CLEAR_VARS)
LOCAL_MODULE := {}
'''.format(project.name,project.name))
	f.write(project.android_header)
	f.write('LOCAL_SRC_FILES := \\\n')
	for file in project.files_cpp:
		f.write('  ../../../../{} \\\n'.format(file))
	for file in project.files_c:
		f.write('  ../../../../{} \\\n'.format(file))

	f.write('\n')
	if project.type == TYPE_EXE:
		f.write('# Needed since ANDROID 5, these programs run on android-16 (Android 4.1+)\n')
		f.write('LOCAL_CFLAGS += -fPIE\n')
		f.write('LOCAL_LDFLAGS += -fPIE -pie\n')
		f.write('\n')
		f.write('include $(BUILD_EXECUTABLE)\n\n')
	if project.type == TYPE_DLL:
		# nothing to do here
		f.write('include $(BUILD_SHARED_LIBRARY)\n\n')
	f.close()

includedirs_7za=[
 "../../../myWindows",
 "../../../",
 "../../../include_windows"
]


includedirs_lzham=[  # FIXME
 "../../../../CPP/7zip/Compress/Lzham/include",
 "../../../../CPP/7zip/Compress/Lzham/lzhamcomp",
 "../../../../CPP/7zip/Compress/Lzham/lzhamdecomp",
 "../../../myWindows",
 "../../../",
 "../../../../",
 "../../../include_windows"
]

import file_7za
import file_7zCon_sfx
import file_7z
import file_7zr
import file_7zG
import file_7zFM
import file_7z_so
import file_Codecs_Rar_so
import file_Codecs_Lzham_so
import file_LzmaCon
import file_Client7z
import file_P7ZIP
import file_TestUI


project_7za=Structure(name="7za",name2="7za",
	type=TYPE_EXE,
	need_AES=True,
	includedirs=includedirs_7za,
	defines=[ "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7za.files_c,
	files_cpp=file_7za.files_cpp,
	cmake_end='''

IF(APPLE)
   TARGET_LINK_LIBRARIES(7za ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7za ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DBREAK_HANDLER \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../7zip/Archive \
	-I../../../7zip/Archive/7z \
	-I../../../7zip/Archive/BZip2 \
	-I../../../7zip/Archive/Common \
	-I../../../7zip/Archive/GZip \
	-I../../../7zip/Archive/Cab \
	-I../../../7zip/Archive/Lzma \
	-I../../../7zip/Archive/Tar \
	-I../../../7zip/Archive/Zip \
	-I../../../7zip/Archive/Split \
	-I../../../7zip/Archive/Z \
	-I../../../7zip/Compress \
       	-I../../../7zip/Crypto \
	-I../../../7zip/UI/Console \
	-I../../../7zip/UI/Common \
	-I../../../Windows \
	-I../../../Common \
	-I../../../7zip/Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows

''')

project_7zr=Structure(name="7zr",name2="7zr",
	type=TYPE_EXE,
	need_AES=True,
	includedirs=includedirs_7za,
	defines=[ "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "_NO_CRYPTO", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7zr.files_c,
	files_cpp=file_7zr.files_cpp,
	cmake_end='''

IF(APPLE)
   TARGET_LINK_LIBRARIES(7zr ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7zr ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DBREAK_HANDLER -D_NO_CRYPTO \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../7zip/Archive \
	-I../../../7zip/Archive/7z \
	-I../../../7zip/Archive/BZip2 \
	-I../../../7zip/Archive/Common \
	-I../../../7zip/Archive/GZip \
	-I../../../7zip/Archive/Cab \
	-I../../../7zip/Archive/Lzma \
	-I../../../7zip/Archive/Tar \
	-I../../../7zip/Archive/Zip \
	-I../../../7zip/Archive/Split \
	-I../../../7zip/Archive/Z \
	-I../../../7zip/Compress \
       	-I../../../7zip/Crypto \
	-I../../../7zip/UI/Console \
	-I../../../7zip/UI/Common \
	-I../../../Windows \
	-I../../../Common \
	-I../../../7zip/Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows

''')

project_7zCon_sfx=Structure(name="7zCon.sfx",name2="7zCon.sfx",
	type=TYPE_EXE,
	need_AES=True,
	includedirs=includedirs_7za,
	defines=[ "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE", "EXTRACT_ONLY", "NO_READ_FROM_CODER", "_SFX" ],
	files_c=file_7zCon_sfx.files_c,
	files_cpp=file_7zCon_sfx.files_cpp,
	cmake_end='''

IF(APPLE)
   TARGET_LINK_LIBRARIES(7zCon.sfx ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7zCon.sfx ${CMAKE_THREAD_LIBS_INIT})
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''')

project_7z=Structure(name="7z",name2="7z_",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7z.files_c,
	files_cpp=file_7z.files_cpp,
	cmake_end='''

find_library(DL_LIB dl)

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(7z_ ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7z_ ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DEXTERNAL_CODECS \
	-DBREAK_HANDLER \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../Windows \
	-I../../../Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows
''')

project_Codecs_Rar=Structure(name="Rar",name2="Rar",
	type=TYPE_DLL,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_Codecs_Rar_so.files_c,
	files_cpp=file_Codecs_Rar_so.files_cpp,
	cmake_end='''

find_library(DL_LIB dl)

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(Rar ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(Rar ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DEXTERNAL_CODECS \
	-DBREAK_HANDLER \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../Windows \
	-I../../../Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows
''')



project_Codecs_Lzham=Structure(name="Lzham",name2="Lzham",
	type=TYPE_DLL,
	need_AES=False,
	includedirs=includedirs_lzham,
	defines=[ "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_Codecs_Lzham_so.files_c,
	files_cpp=file_Codecs_Lzham_so.files_cpp,
	cmake_end='''

find_library(DL_LIB dl)

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(Lzham ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(Lzham ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DEXTERNAL_CODECS \
	-DBREAK_HANDLER \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../Windows \
	-I../../../Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows \
-I../../../../CPP/7zip/Compress/Lzham/include \
-I../../../../CPP/7zip/Compress/Lzham/lzhamcomp \
-I../../../../CPP/7zip/Compress/Lzham/lzhamdecomp

''')


project_7zG=Structure(name="7zG",name2="7zG",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "LANG",  "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7zG.files_c,
	files_cpp=file_7zG.files_cpp,
	cmake_end='''

IF(APPLE)
  add_definitions(-DENV_MACOSX  -D__WXMAC__)
ENDIF(APPLE)

find_package(wxWidgets COMPONENTS core base adv REQUIRED)

find_library(DL_LIB dl)

include( ${wxWidgets_USE_FILE} )

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(7zG ${COREFOUNDATION_LIBRARY} ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7zG ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''')

project_7zFM=Structure(name="7zFM_do_not_use",name2="7zFM_do_not_use",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "LANG", "NEW_FOLDER_INTERFACE", "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7zFM.files_c,
	files_cpp=file_7zFM.files_cpp,
	cmake_end='''

IF(APPLE)
  add_definitions(-DENV_MACOSX  -D__WXMAC__)
ENDIF(APPLE)

find_package(wxWidgets COMPONENTS core base adv REQUIRED)

find_library(DL_LIB dl)

include( ${wxWidgets_USE_FILE} )

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(7zFM_do_not_use ${COREFOUNDATION_LIBRARY} ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7zFM_do_not_use ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''')

project_Format7zFree=Structure(name="7z",name2="7z",
	type=TYPE_DLL,
	need_AES=True,
	includedirs=includedirs_7za,
	defines=[ "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_7z_so.files_c,
	files_cpp=file_7z_so.files_cpp,
	cmake_end='''

SET_TARGET_PROPERTIES(7z PROPERTIES PREFIX "")

IF(APPLE)
   TARGET_LINK_LIBRARIES(7z ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(7z ${CMAKE_THREAD_LIBS_INIT})
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)
	
''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DEXTERNAL_CODECS \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../Windows \
	-I../../../Common \
	-I../../../../C \
	-I../../../myWindows \
	-I../../../ \
	-I../../../include_windows

''')

project_LzmaCon=Structure(name="LzmaCon",name2="LzmaCon",
	type=TYPE_EXE,
	need_AES=True,
	includedirs=includedirs_7za,
	defines=[ "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX"  ],
	files_c=file_LzmaCon.files_c,
	files_cpp=file_LzmaCon.files_cpp,
	cmake_end='''

IF(APPLE)
   TARGET_LINK_LIBRARIES(LzmaCon ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(LzmaCon ${CMAKE_THREAD_LIBS_INIT})
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-I../../../7zip/Archive \
	-I../../../7zip/Archive/7z \
	-I../../../7zip/Archive/BZip2 \
	-I../../../7zip/Archive/Common \
	-I../../../7zip/Archive/GZip \
	-I../../../7zip/Archive/Cab \
	-I../../../7zip/Archive/Lzma \
	-I../../../7zip/Archive/Tar \
	-I../../../7zip/Archive/Zip \
	-I../../../7zip/Archive/Split \
	-I../../../7zip/Archive/Z \
	-I../../../7zip/Compress \
       	-I../../../7zip/Crypto \
	-I../../../7zip/UI/Console \
	-I../../../7zip/UI/Common \
	-I../../../Windows \
	-I../../../Common \
	-I../../../7zip/Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows

''')

project_Client7z=Structure(name="Client7z",name2="Client7z",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_Client7z.files_c,
	files_cpp=file_Client7z.files_cpp,
	cmake_end='''

find_library(DL_LIB dl)

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(Client7z ${COREFOUNDATION_LIBRARY} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(Client7z ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''',
android_header=r'''
LOCAL_CFLAGS := -DANDROID_NDK  -fexceptions \
	-DNDEBUG -D_REENTRANT -DENV_UNIX \
	-DEXTERNAL_CODECS \
	-DBREAK_HANDLER \
	-DUNICODE -D_UNICODE -DUNIX_USE_WIN_FILE \
	-I../../../Windows \
	-I../../../Common \
	-I../../../../C \
-I../../../myWindows \
-I../../../ \
-I../../../include_windows
''')

project_P7ZIP=Structure(name="P7ZIP",name2="P7ZIP",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "LANG", "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_P7ZIP.files_c,
	files_cpp=file_P7ZIP.files_cpp,
	cmake_end='''

IF(APPLE)
  add_definitions(-DENV_MACOSX  -D__WXMAC__)
ENDIF(APPLE)

find_package(wxWidgets COMPONENTS core base adv REQUIRED)

find_library(DL_LIB dl)

include( ${wxWidgets_USE_FILE} )

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(P7ZIP ${COREFOUNDATION_LIBRARY} ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(P7ZIP ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''')

project_TestUI=Structure(name="TestUI",name2="TestUI",
	type=TYPE_EXE,
	need_AES=False,
	includedirs=includedirs_7za,
	defines=[ "LANG", "EXTERNAL_CODECS", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE", "_REENTRANT", "ENV_UNIX", "BREAK_HANDLER", "UNICODE", "_UNICODE", "UNIX_USE_WIN_FILE" ],
	files_c=file_TestUI.files_c,
	files_cpp=file_TestUI.files_cpp,
	cmake_end='''

IF(APPLE)
  add_definitions(-DENV_MACOSX  -D__WXMAC__)
ENDIF(APPLE)

find_package(wxWidgets COMPONENTS core base adv REQUIRED)

find_library(DL_LIB dl)

include( ${wxWidgets_USE_FILE} )

link_directories(${DL_LIB_PATH})

IF(APPLE)
   TARGET_LINK_LIBRARIES(TestUI ${COREFOUNDATION_LIBRARY} ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT})
ELSE(APPLE)
  IF(HAVE_PTHREADS)
   TARGET_LINK_LIBRARIES(TestUI ${wxWidgets_LIBRARIES} ${CMAKE_THREAD_LIBS_INIT} dl)
  ENDIF(HAVE_PTHREADS)
ENDIF(APPLE)

''')
generate_makefile_list('../CPP/7zip/Bundles/Alone/makefile.list',project_7za)
generate_makefile_list('../CPP/7zip/Bundles/Alone7z/makefile.list',project_7zr)
generate_makefile_list('../CPP/7zip/UI/Console/makefile.list',project_7z)
generate_makefile_list('../CPP/7zip/Bundles/Format7zFree/makefile.list',project_Format7zFree)
generate_makefile_list('../CPP/7zip/Compress/Rar/makefile.list',project_Codecs_Rar,'../../../../bin/Codecs')
generate_makefile_list('../CPP/7zip/Compress/Lzham/makefile.list',project_Codecs_Lzham,'../../../../bin/Codecs')
generate_makefile_list('../CPP/7zip/Bundles/SFXCon/makefile.list',project_7zCon_sfx)
generate_makefile_list('../CPP/7zip/UI/GUI/makefile.list',project_7zG)
generate_makefile_list('../CPP/7zip/UI/FileManager/makefile.list',project_7zFM)
generate_makefile_list('../CPP/7zip/Bundles/LzmaCon/makefile.list',project_LzmaCon)
generate_makefile_list('../CPP/7zip/UI/Client7z/makefile.list',project_Client7z)
generate_makefile_list('../CPP/7zip/UI/P7ZIP/makefile.list',project_P7ZIP)
generate_makefile_list('../CPP/7zip/TEST/TestUI/makefile.list',project_TestUI)

generate_pro('../CPP/7zip/QMAKE/7za/7za.pro',project_7za)
generate_pro('../CPP/7zip/QMAKE/7zr/7zr.pro',project_7zr)
generate_pro('../CPP/7zip/QMAKE/7z_/7z_.pro',project_7z)
generate_pro('../CPP/7zip/QMAKE/Format7zFree/Format7zFree.pro',project_Format7zFree)
generate_pro('../CPP/7zip/QMAKE/Rar/Rar.pro',project_Codecs_Rar)
generate_pro('../CPP/7zip/QMAKE/Lzham/Lzham.pro',project_Codecs_Lzham)

generate_premake4('../CPP/7zip/PREMAKE/premake4.lua',project_7za)

generate_cmake('../CPP/7zip/CMAKE/7za/CMakeLists.txt',project_7za)
generate_cmake('../CPP/7zip/CMAKE/7z_/CMakeLists.txt',project_7z)
generate_cmake('../CPP/7zip/CMAKE/7zG/CMakeLists.txt',project_7zG)
generate_cmake('../CPP/7zip/CMAKE/7zFM/CMakeLists.txt',project_7zFM)
generate_cmake('../CPP/7zip/CMAKE/7zr/CMakeLists.txt',project_7zr)
generate_cmake('../CPP/7zip/CMAKE/Format7zFree/CMakeLists.txt',project_Format7zFree)


generate_android_mk('../CPP/ANDROID/7za/jni/Android.mk',project_7za)
generate_android_mk('../CPP/ANDROID/7zr/jni/Android.mk',project_7zr)
generate_android_mk('../CPP/ANDROID/7z/jni/Android.mk',project_7z)
generate_android_mk('../CPP/ANDROID/Format7zFree/jni/Android.mk',project_Format7zFree)
generate_android_mk('../CPP/ANDROID/Lzham/jni/Android.mk',project_Codecs_Lzham)


#FIXME:7zr-CPP/7zip/Bundles/Alone7z






files_c=[
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/Common/FileStreams.cpp',
 'CPP/7zip/UI/Client7z/Client7z.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/UTFConvert.cpp',
 'CPP/Common/Wildcard.cpp',
 'CPP/Windows/DLL.cpp',
 'CPP/Windows/FileDir.cpp',
 'CPP/Windows/FileFind.cpp',
 'CPP/Windows/FileIO.cpp',
 'CPP/Windows/FileName.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/PropVariantConv.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]





files_c=[
 'C/Alloc.c',
]

files_cpp=[
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Compress/CodecExports.cpp',
 'CPP/7zip/Compress/DllExportsCompress.cpp',
 'CPP/7zip/Compress/Lzham/LzhamRegister.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Windows/System.cpp',

 # lzhamcomp
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_lzbase.cpp',
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_lzcomp.cpp',
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_lzcomp_internal.cpp',
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_lzcomp_state.cpp',
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_match_accel.cpp',
 'CPP/7zip/Compress/Lzham/lzhamcomp/lzham_pthreads_threading.cpp',

 # lzhamdecomp
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_assert.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_checksum.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_huffman_codes.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_lzdecomp.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_lzdecompbase.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_mem.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_platform.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_prefix_coding.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_symbol_codec.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_timer.cpp',
 'CPP/7zip/Compress/Lzham/lzhamdecomp/lzham_vector.cpp', 
 
 # lzhamlib
 'CPP/7zip/Compress/Lzham/lzhamlib/lzham_lib.cpp', 
]






files_c=[
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/Alloc.c',
 'C/Bra86.c',
 'C/CpuArch.c',
 'C/LzFind.c',
 'C/LzFindMt.c',
 'C/LzmaDec.c',
 'C/LzmaEnc.c',
 'C/Lzma86Dec.c',
 'C/Lzma86Enc.c',
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/Bundles/LzmaCon/LzmaAlone.cpp',
 'CPP/7zip/Common/CWrappers.cpp',
 'CPP/7zip/Common/CreateCoder.cpp',
 'CPP/7zip/Common/FileStreams.cpp',
 'CPP/7zip/Common/FilterCoder.cpp',
 'CPP/7zip/Common/MethodProps.cpp',
 'CPP/7zip/Common/OutBuffer.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Compress/LzmaDecoder.cpp',
 'CPP/7zip/Compress/LzmaEncoder.cpp',
 'CPP/7zip/Compress/LzmaRegister.cpp',
 'CPP/7zip/UI/Common/Bench.cpp',
 'CPP/7zip/UI/Console/BenchCon.cpp',
 'CPP/7zip/UI/Console/ConsoleClose.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/CommandLineParser.cpp',
 'CPP/Common/CrcReg.cpp',
 'CPP/Common/C_FileIO.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/NewHandler.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/StringToInt.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/System.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]

# 'CPP/Windows/FileIO.cpp',




#!/usr/bin/env python

import fnmatch
import os
import sys

dir0='CPP/7zip/Bundles/Alone'
file0='Utils/file_7za.py'

dir0='CPP/7zip/Bundles/SFXCon'
file0='Utils/file_7zCon_sfx.py'

dir0='CPP/7zip/UI/Console'
file0='Utils/file_7z.py'

dir0='CPP/7zip/Compress/Rar'
file0='Utils/file_Codecs_Rar_so.py'

dir0='CPP/7zip/Bundles/Format7zFree'
file0='Utils/file_7z_so.py'

dir0='CPP/7zip/UI/GUI'
file0='Utils/file_7zG.py'

dir0='CPP/7zip/Bundles/Alone7z'
file0='Utils/file_7zr.py'

dir0='CPP/7zip/UI/FileManager'
file0='Utils/file_7zFM.py'

dir0='CPP/7zip/Bundles/LzmaCon'
file0='Utils/file_LzmaCon.py'

dir0='CPP/7zip/UI/Client7z'
file0='Utils/file_Client7z.py'

dir0='CPP/7zip/UI/P7ZIP'
file0='Utils/file_P7ZIP.py'

dir0='CPP/7zip/TEST/TestUI'
file0='Utils/file_TestUI.py'


listO=[]

for file in os.listdir(dir0):
	if fnmatch.fnmatch(file, '*.o'):
		# print(file)
		file=os.path.splitext(file)[0]
		listO.append(file)


listO.sort()

listc=[]
listcpp=[]

for file in listO:
	# print("Searching " + file + " ...")
	f_c= None
	f_cpp = None
	file_c = file + '.c'
	file_cpp = file + '.cpp'
	for root, dirs, files in os.walk("."):
		for f in files:
			if f == file_c:
				f_c=os.path.join(root, f)
			if f == file_cpp:
				f_cpp=os.path.join(root, f)
	if f_c is None:
		if f_cpp is None:
			print("Cannot find {}".format(file))
			sys.exit(-1)
		else:
			listcpp.append(f_cpp[2:])
	else:
		if f_cpp is None:
			listc.append(f_c[2:])
		else:
			print("error {} => {} and {}".format(file,f_c,f_cpp))
			sys.exit(-1)

f=open(file0,'w')
f.write('\n')

listc.sort()
listcpp.sort()

f.write('files_c=[\n')
for file in listc:
	f.write(" '{}',\n".format(file))
f.write(']\n')
f.write('\n')
f.write('files_cpp=[\n')
for file in listcpp:
	f.write(" '{}',\n".format(file))
f.write(']\n')
f.write('\n')
f.close()






files_c=[
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/Alloc.c',
 'C/CpuArch.c',
 'C/Ppmd7.c',
 'C/Ppmd7Dec.c',
]

files_cpp=[
 'CPP/7zip/Common/InBuffer.cpp',
 'CPP/7zip/Common/OutBuffer.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Compress/CodecExports.cpp',
 'CPP/7zip/Compress/DllExportsCompress.cpp',
 'CPP/7zip/Compress/LzOutWindow.cpp',
 'CPP/7zip/Compress/Rar1Decoder.cpp',
 'CPP/7zip/Compress/Rar2Decoder.cpp',
 'CPP/7zip/Compress/Rar3Decoder.cpp',
 'CPP/7zip/Compress/Rar3Vm.cpp',
 'CPP/7zip/Compress/Rar5Decoder.cpp',
 'CPP/7zip/Compress/RarCodecsRegister.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
]





files_c=[
 'C/7zCrc.c',
 'C/7zCrcOpt.c',
 'C/Aes.c',
 'C/Alloc.c',
 'C/Bcj2.c',
 'C/Bra.c',
 'C/Bra86.c',
 'C/BraIA64.c',
 'C/CpuArch.c',
 'C/Delta.c',
 'C/Lzma2Dec.c',
 'C/LzmaDec.c',
 'C/Ppmd7.c',
 'C/Ppmd7Dec.c',
 'C/Sha256.c',
 'C/Threads.c',
]

files_cpp=[
 'CPP/7zip/Archive/7z/7zDecode.cpp',
 'CPP/7zip/Archive/7z/7zExtract.cpp',
 'CPP/7zip/Archive/7z/7zHandler.cpp',
 'CPP/7zip/Archive/7z/7zHeader.cpp',
 'CPP/7zip/Archive/7z/7zIn.cpp',
 'CPP/7zip/Archive/7z/7zRegister.cpp',
 'CPP/7zip/Archive/Common/CoderMixer2.cpp',
 'CPP/7zip/Archive/Common/ItemNameUtils.cpp',
 'CPP/7zip/Archive/Common/OutStreamWithCRC.cpp',
 'CPP/7zip/Bundles/SFXCon/SfxCon.cpp',
 'CPP/7zip/Common/CWrappers.cpp',
 'CPP/7zip/Common/CreateCoder.cpp',
 'CPP/7zip/Common/FilePathAutoRename.cpp',
 'CPP/7zip/Common/FileStreams.cpp',
 'CPP/7zip/Common/FilterCoder.cpp',
 'CPP/7zip/Common/InBuffer.cpp',
 'CPP/7zip/Common/LimitedStreams.cpp',
 'CPP/7zip/Common/OutBuffer.cpp',
 'CPP/7zip/Common/ProgressUtils.cpp',
 'CPP/7zip/Common/StreamBinder.cpp',
 'CPP/7zip/Common/StreamObjects.cpp',
 'CPP/7zip/Common/StreamUtils.cpp',
 'CPP/7zip/Common/VirtThread.cpp',
 'CPP/7zip/Compress/Bcj2Coder.cpp',
 'CPP/7zip/Compress/Bcj2Register.cpp',
 'CPP/7zip/Compress/BcjCoder.cpp',
 'CPP/7zip/Compress/BcjRegister.cpp',
 'CPP/7zip/Compress/BranchMisc.cpp',
 'CPP/7zip/Compress/BranchRegister.cpp',
 'CPP/7zip/Compress/CopyCoder.cpp',
 'CPP/7zip/Compress/CopyRegister.cpp',
 'CPP/7zip/Compress/DeltaFilter.cpp',
 'CPP/7zip/Compress/Lzma2Decoder.cpp',
 'CPP/7zip/Compress/Lzma2Register.cpp',
 'CPP/7zip/Compress/LzmaDecoder.cpp',
 'CPP/7zip/Compress/LzmaRegister.cpp',
 'CPP/7zip/Compress/PpmdDecoder.cpp',
 'CPP/7zip/Compress/PpmdRegister.cpp',
 'CPP/7zip/Crypto/7zAes.cpp',
 'CPP/7zip/Crypto/7zAesRegister.cpp',
 'CPP/7zip/Crypto/MyAes.cpp',
 'CPP/7zip/UI/Common/ArchiveExtractCallback.cpp',
 'CPP/7zip/UI/Common/ArchiveOpenCallback.cpp',
 'CPP/7zip/UI/Common/DefaultName.cpp',
 'CPP/7zip/UI/Common/Extract.cpp',
 'CPP/7zip/UI/Common/ExtractingFilePath.cpp',
 'CPP/7zip/UI/Common/LoadCodecs.cpp',
 'CPP/7zip/UI/Common/OpenArchive.cpp',
 'CPP/7zip/UI/Common/PropIDUtils.cpp',
 'CPP/7zip/UI/Console/ConsoleClose.cpp',
 'CPP/7zip/UI/Console/ExtractCallbackConsole.cpp',
 'CPP/7zip/UI/Console/List.cpp',
 'CPP/7zip/UI/Console/MainAr.cpp',
 'CPP/7zip/UI/Console/OpenCallbackConsole.cpp',
 'CPP/7zip/UI/Console/PercentPrinter.cpp',
 'CPP/7zip/UI/Console/UserInputUtils.cpp',
 'CPP/Common/CRC.cpp',
 'CPP/Common/CommandLineParser.cpp',
 'CPP/Common/IntToString.cpp',
 'CPP/Common/MyString.cpp',
 'CPP/Common/MyVector.cpp',
 'CPP/Common/MyWindows.cpp',
 'CPP/Common/StdInStream.cpp',
 'CPP/Common/StdOutStream.cpp',
 'CPP/Common/StringConvert.cpp',
 'CPP/Common/UTFConvert.cpp',
 'CPP/Common/Wildcard.cpp',
 'CPP/Windows/ErrorMsg.cpp',
 'CPP/Windows/FileDir.cpp',
 'CPP/Windows/FileFind.cpp',
 'CPP/Windows/FileIO.cpp',
 'CPP/Windows/FileName.cpp',
 'CPP/Windows/PropVariant.cpp',
 'CPP/Windows/PropVariantConv.cpp',
 'CPP/Windows/Synchronization.cpp',
 'CPP/Windows/System.cpp',
 'CPP/myWindows/mySplitCommandLine.cpp',
 'CPP/myWindows/wine_date_and_time.cpp',
]

